@@ -160,7 +160,7 @@ class BaseDocument(object):
             is_reference_field = self.is_reference_field(field)
             value = field.get_value(self._values.get(name, None))
 
-            if is_reference_field and value is not None and not isinstance(value, field._reference_document_type):
+            if is_reference_field and value is not None and not isinstance(value, field.reference_type):
                 message = "The property '%s' can't be accessed before calling 'load_references'" + \
                     " on its instance first (%s) or setting __lazy__ to False in the %s class."
 
